/*
	swig_etirm_types.h

	Definition of types that are referenced in swig_etirm.h.
	
	IRT Command Language (ICL)
	http://www.b-a-h.com/software/irt/icl

	Author(s): Brad Hanson (http://www.b-a-h.com/)
	See the file LICENSE for information on usage and redistribution.

	Copyright (c) 2000-2002, Bradley A. Hanson

*/

#ifndef SWIG_ETIRM_TYPES_H_
#define SWIG_ETIRM_TYPES_H_

#ifdef ETIRM_NO_DIR_PREFIX
#include "etirmtypes.h"
#include "ItemNR.h"
#include "DiscreteLatentDist.h"
#include "ExamineeGrpCov.h"
#else
#include "etirm/etirmtypes.h"
#include "etirm/ItemNR.h"
#include "etirm/DiscreteLatentDist.h"
#include "etirm/ExamineeGrpCov.h"
#endif

 // for random number generator (http://www.boost.org)
#include <boost/random/mersenne_twister.hpp>

// SWIG cannot handle the template arguments
#ifndef SWIG

// Vector of item responses
typedef SCPPNT::Vector<etirm::Response> ResponseVector;

// Class to hold information about discrete latent variable distribution
typedef etirm::DiscreteLatentDist<etirm::Real> lvdist_type;

// Class to hold information about examinees
typedef etirm::ExamineeGrpCov<ResponseVector, etirm::RealVector> examinee_type;

// Type used for array of items. Using ItemNR allows different items to be modeled
// by different classes descendent from ItemNR (e.g., the 3PL model could be used for
// some items, and the generalized partial credit model used for other items).
typedef etirm::ItemNR<lvdist_type> item_type;

// Use the Mersenne Twister (http://www.math.keio.ac.jp/matumoto/emt.html)
// from the Boost random number library
// (http://www.boost.org/libs/random/index.html) 
// as random number generator.
typedef boost::mt19937 random_type;
	

#endif // SWIG

#endif